/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ElementRef, Renderer2 } from '@angular/core';
import { CheckBoxRounded, InputSize } from '../common/models';
import * as i0 from "@angular/core";
/**
 * Renders the [Kendo UI CheckBox]({% slug overview_checkbox %}) input component.
 * Apply this directive to `input type="checkbox"` HTML elements.
 *
 * @example
 * ```html
 * <input type="checkbox" kendoCheckBox />
 * ```
 */
export declare class CheckBoxDirective {
    private renderer;
    private hostElement;
    kendoClass: boolean;
    /**
     * Sets the `size` property to specify the width and height of the CheckBox
     * ([see example]({% slug appearance_checkboxdirective %}#toc-size)).
     *
     * @default 'medium'
     */
    set size(size: InputSize);
    get size(): InputSize;
    /**
     * Sets the `rounded` property to specify the border radius of the CheckBox
     * ([see example](slug:appearance_checkboxdirective#toc-roundness)).
     *
     * @default 'medium'
     *
     */
    set rounded(rounded: CheckBoxRounded);
    get rounded(): CheckBoxRounded;
    private _size;
    private _rounded;
    constructor(renderer: Renderer2, hostElement: ElementRef);
    ngAfterViewInit(): void;
    private handleClasses;
    static ɵfac: i0.ɵɵFactoryDeclaration<CheckBoxDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<CheckBoxDirective, "input[kendoCheckBox]", never, { "size": { "alias": "size"; "required": false; }; "rounded": { "alias": "rounded"; "required": false; }; }, {}, never, never, true, never>;
}
