/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ElementRef, Renderer2 } from '@angular/core';
import { InputSize } from '../common/models';
import * as i0 from "@angular/core";
/**
 * Represents the directive that renders the Kendo UI RadioButton input component.
 * Place the directive on `input type="radio"` HTML elements.
 *
 * @example
 * ```html
 * <input type="radio" kendoRadioButton />
 * ```
 */
export declare class RadioButtonDirective {
    private renderer;
    private hostElement;
    kendoClass: boolean;
    /**
     * Specifies the `size` of the RadioButton. The `size` property changes the width and height of the RadioButton ([see example]({% slug appearance_radiobuttondirective %}#toc-size)).
     *
     * @default "medium"
     */
    set size(size: InputSize);
    get size(): InputSize;
    private _size;
    constructor(renderer: Renderer2, hostElement: ElementRef);
    ngAfterViewInit(): void;
    private handleClasses;
    static ɵfac: i0.ɵɵFactoryDeclaration<RadioButtonDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<RadioButtonDirective, "input[kendoRadioButton]", never, { "size": { "alias": "size"; "required": false; }; }, {}, never, never, true, never>;
}
