/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { SeparatorOrientation } from '@progress/kendo-angular-common';
import * as i0 from "@angular/core";
/**
 * Represents a separator in the content of components like TextArea and TextBox. ([see examples]({% slug adornments_textbox %}#toc-separator)).
 *
 * @example
 * ```html
 * <kendo-textbox>
 *   <ng-template kendoTextBoxSuffixTemplate>
 *     <kendo-input-separator></kendo-input-separator>
 *     <button kendoButton icon="image"></button>
 *   </ng-template>
 * </kendo-textbox>
 * ```
 */
export declare class InputSeparatorComponent {
    /**
     * Sets the orientation of the separator. Use this for the adornments of the [`TextAreaComponent`](slug:api_inputs_textareacomponent).
     *
     * @default 'vertical'
     */
    orientation: SeparatorOrientation;
    get vertical(): boolean;
    get horizontal(): boolean;
    hostClass: boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<InputSeparatorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<InputSeparatorComponent, "kendo-input-separator, kendo-textbox-separator", never, { "orientation": { "alias": "orientation"; "required": false; }; }, {}, never, never, true, never>;
}
