/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * Sets the title for the ticks ([see example]({% slug ticks_slider %}#toc-titles)).
 * By default, each tick uses its Slider value as the title.
 * If you use a callback function, it receives the component value and returns a string for the title.
 *
 * @example
 * ```typescript
 * @Component({
 *   selector: "my-app",
 *   template: `
 *     <kendo-slider [title]="title"></kendo-slider>
 *   `,
 * })
 * export class AppComponent {
 *   // Use a callback function to capture the 'this' execution context of the class.
 *   public title = (value: number): string => {
 *     return `${this.numbers[value]}`;
 *   };
 * }
 * ```
 */
export type SliderTickTitleCallback = (value: number) => string;
